# Complete Fix Guide (absorbed)

Historical fix guide. See [docs/_archive/XWFORMATS_COMPLETE_FIX_GUIDE.md](../_archive/XWFORMATS_COMPLETE_FIX_GUIDE.md). Current status: [REF_22_PROJECT.md](../REF_22_PROJECT.md), [REF_35_REVIEW.md](../REF_35_REVIEW.md).
